%global libsolv_version 0.7.21
%global libmodulemd_version 2.13.0
%global librepo_version 1.13.1
%global dnf_conflict 4.11.0
%global swig_version 3.0.12

# Keep valgrind tests switched off for now
%bcond_with valgrind

%define somajor 2
%define libname %mklibname dnf %{somajor}
%define devname %mklibname dnf -d

Name:           libdnf
Version:        0.70.1
Release:        %mkrel 1
Summary:        Library providing simplified C and Python API to libsolv
Group:          System/Packaging
License:        LGPL-2.1-or-later
URL:            https://github.com/rpm-software-management/%{name}
Source0:        https://github.com/rpm-software-management/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gettext
BuildRequires:  gpgme-devel
BuildRequires:  libsolv-devel >= %{libsolv_version}
BuildRequires:  pkgconfig(librepo) >= %{librepo_version}
BuildRequires:  pkgconfig(check)
%if %{with valgrind}
BuildRequires:  valgrind
%endif
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.46.0
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  rpm-devel >= 4.15.0
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
BuildRequires:  pkgconfig(smartcols)
BuildRequires:  pkgconfig(zck) >= 0.9.11

%description
A library providing simplified C and Python API to libsolv.

%package -n %{libname}
Summary:        Package library providing simplified interface to libsolv
Group:          System/Libraries
Provides:       %{name}%{somajor} = %{version}-%{release}
Provides:       %{name}%{somajor}%{?_isa} = %{version}-%{release}
Requires:       %{mklibname solv 1}%{?_isa} >= %{libsolv_version}
Requires:       %{mklibname modulemd 2}%{?_isa} >= %{libmodulemd_version}
Requires:       %{mklibname repo 0}%{?_isa} >= %{librepo_version}
Recommends:     %{name}-lang = %{version}-%{release}
# gobject-introspection is no longer used
Obsoletes:      %{mklibname dnf-gir 1.0} < 0.15.0
# Python 2 bindings are no longer provided
Obsoletes:      python2-hawkey < 0.24.1
Obsoletes:      python2-libdnf < 0.24.1

%description -n %{libname}
This library provides a simple interface to libsolv and is currently
used by PackageKit and rpm-ostree.

%package -n %{devname}
Summary:        Development files for %{name}
Group:          Development/C
Provides:       %{name}-devel%{?_isa} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
Development files for %{name}.

%package lang
Summary:        Translations for the libdnf library
Group:          System/Internationalization
Requires:       %{name}%{somajor} = %{version}-%{release}
BuildArch:      noarch

%description lang
Translation data for the libdnf library.


%package -n python3-%{name}
Summary:        Python 3 bindings for the libdnf library
Group:          Development/Python
%{?python_provide:%python_provide python3-%{name}}
Requires:       %{libname}%{?_isa} = %{version}-%{release}
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  swig >= %{swig_version}

%description -n python3-%{name}
Python 3 bindings for the libdnf library.


%package -n hawkey-man
Summary:        Documentation for the hawkey Python bindings
Group:          Development/Python
BuildRequires:  python3-nose
BuildRequires:  python3-sphinx
# hawkey-devel prior to 0.6.3-6 had the man page
Obsoletes:      hawkey-devel < 0.6.3-6
BuildArch:      noarch

%description -n hawkey-man
Documentation for the hawkey Python bindings.

%package -n python3-hawkey
Summary:        Python 3 bindings for the hawkey interface
Group:          Development/Python
%{?python_provide:%python_provide python3-hawkey}
BuildRequires:  python3-devel
BuildRequires:  python3-nose
Requires:       %{libname}%{?_isa} = %{version}-%{release}
# hawkey module now uses libdnf module
Requires:       python3-%{name}%{?_isa} = %{version}-%{release}
Recommends:     hawkey-man = %{version}-%{release}
# Fix problem with hawkey - dnf version incompatibility
Conflicts:      python3-dnf < %{dnf_conflict}
Obsoletes:      %{_lib}hawkey-devel < 0.6.4-6
Obsoletes:      %{_lib}hawkey2 < 0.6.4-6

%description -n python3-hawkey
Python 3 bindings for libdnf through the hawkey interface.

%prep
%autosetup -p1


%build
%cmake -DPYTHON_DESIRED:FILEPATH=%{__python3} %{!?with_valgrind:-DDISABLE_VALGRIND=1} -DENABLE_SOLV_URPMREORDER=1
%cmake_build


%check
# The test suite doesn't automatically know to look at the "built"
# library, so we force it by creating an LD_LIBRARY_PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}

if [ "$(id -u)" == "0" ] ; then
        cat <<ERROR 1>&2
Package tests cannot be run under superuser account.
Please build the package as non-root user.
ERROR
        exit 1
fi
make ARGS="-V" test -C %{_vpath_builddir}


%install
%cmake_install

%find_lang %{name}


%files -n %{libname}
%license COPYING
%doc README.md AUTHORS
%{_libdir}/%{name}.so.%{somajor}
# Plugins are compiled against the library itself
%dir %{_libdir}/libdnf
%dir %{_libdir}/libdnf/plugins
%{_libdir}/libdnf/plugins/README

%files -n %{devname}
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/
%doc %{_datadir}/gtk-doc/html/%{name}/

%files lang -f %{name}.lang
%license COPYING

%files -n python3-libdnf
%{python3_sitearch}/libdnf/

%files -n hawkey-man
%{_mandir}/man3/hawkey.3*

%files -n python3-hawkey
%{python3_sitearch}/hawkey/



%changelog
* Mon May 22 2023 luigiwalser <luigiwalser> 0.70.1-1.mga9
+ Revision: 1957771
- 0.70.1

* Wed Apr 05 2023 luigiwalser <luigiwalser> 0.70.0-1.mga9
+ Revision: 1951446
- 0.70.0

* Thu Aug 18 2022 luigiwalser <luigiwalser> 0.68.0-1.mga9
+ Revision: 1878554
- 0.68.0

* Tue May 10 2022 luigiwalser <luigiwalser> 0.67.0-1.mga9
+ Revision: 1857370
- 0.67.0

* Fri Mar 18 2022 luigiwalser <luigiwalser> 0.66.0-1.mga9
+ Revision: 1798884
- 0.66.0

* Sun Feb 06 2022 wally <wally> 0.65.0-2.mga9
+ Revision: 1772332
- rebuild for python3.10

* Tue Nov 23 2021 ngompa <ngompa> 0.65.0-1.mga9
+ Revision: 1758696
- Update to 0.65.0

* Sat Oct 02 2021 wally <wally> 0.64.0-2.mga9
+ Revision: 1748097
- rebuild for openssl 3.0.0

* Sun Sep 26 2021 luigiwalser <luigiwalser> 0.64.0-1.mga9
+ Revision: 1746477
- 0.64.0

* Fri Jun 18 2021 joequant <joequant> 0.63.1-1.mga9
+ Revision: 1731174
- update to 0.64

* Mon Mar 15 2021 wally <wally> 0.58.0-2.mga9
+ Revision: 1703529
- rebuild for python 3.9

* Wed Feb 03 2021 ngompa <ngompa> 0.58.0-1.mga8
+ Revision: 1674595
- Update to 0.58.0

* Sun Dec 06 2020 ngompa <ngompa> 0.55.2-1.mga8
+ Revision: 1653806
- Update to 0.55.2

* Sun Nov 29 2020 luigiwalser <luigiwalser> 0.48.0-3.mga8
+ Revision: 1650339
- rebuild for json-c

* Sat Oct 24 2020 akien <akien> 0.48.0-2.mga8
+ Revision: 1639014
- Add patch to fix test build issue
- Properly obsolete hawkey SRPM

* Tue Jul 07 2020 ngompa <ngompa> 0.48.0-1.mga8
+ Revision: 1602733
- Update to 0.48.0

* Thu Feb 27 2020 ngompa <ngompa> 0.45.0-1.mga8
+ Revision: 1550981
- Update to 0.45.0

* Wed Feb 19 2020 umeabot <umeabot> 0.43.1-2.mga8
+ Revision: 1543446
- Mageia 8 Mass Rebuild

* Sun Jan 19 2020 ngompa <ngompa> 0.43.1-1.mga8
+ Revision: 1481586
- Update to 0.43.1
+ wally <wally>
- build with new cmake macros

* Sun Dec 08 2019 ngompa <ngompa> 0.39.1-1.mga8
+ Revision: 1465178
- Update to 0.39.1

* Sat Nov 02 2019 joequant <joequant> 0.35.5-2.mga8
+ Revision: 1457353
- Fix leaking log handlers in Sack (rhbz#1758737)

* Sat Nov 02 2019 joequant <joequant> 0.35.5-1.mga8
+ Revision: 1457321
- update to 0.35.5

* Sun Sep 08 2019 wally <wally> 0.33.0-2.mga8
+ Revision: 1438354
- rebuild for python3.8

* Sun May 12 2019 ngompa <ngompa> 0.33.0-1.mga7
+ Revision: 1397463
- Update to 0.33.0

* Fri Apr 26 2019 ngompa <ngompa> 0.31.0-1.mga7
+ Revision: 1395522
- Update to 0.31.0

* Mon Apr 01 2019 ngompa <ngompa> 0.28.1-1.mga7
+ Revision: 1384422
- Update to 0.28.1
- Drop patches that are part of this release

* Fri Jan 11 2019 ngompa <ngompa> 0.24.1-2.mga7
+ Revision: 1354973
- hawkey Python module requires libdnf Python module now

* Mon Jan 07 2019 ngompa <ngompa> 0.24.1-1.mga7
+ Revision: 1350394
- Rebase to 0.24.1
- Drop merged patches and backport new fixes from upstream
- Add patches for fixing fetching zchunk repodata
- Drop Python 2 subpackages

* Sat Jan 05 2019 wally <wally> 0.22.0-4.mga7
+ Revision: 1349810
- rebuild for python3.7

* Sun Oct 28 2018 ngompa <ngompa> 0.22.0-3.mga7
+ Revision: 1326346
- Rebuild with libsolv 0.7.0 again for ARM

* Sun Oct 28 2018 ngompa <ngompa> 0.22.0-2.mga7
+ Revision: 1326330
- Sync patches from Fedora backported from upstream
- Rebuild against libsolv 0.7.0

* Tue Oct 16 2018 ngompa <ngompa> 0.22.0-1.mga7
+ Revision: 1320720
- Update to 0.22.0

* Sat Sep 15 2018 ngompa <ngompa> 0.19.1-1.mga7
+ Revision: 1259049
- Rebase to 0.19.1
- Sync patches from Fedora
- Fix build to correctly link with GPGME

* Sat Aug 04 2018 ngompa <ngompa> 0.16.1-1.mga7
+ Revision: 1247277
- Update to 0.16.1
- Drop hawkey-man to Recommends on pythonX-hawkey
- Add lang subpackage for lang data

* Sat Jun 30 2018 ngompa <ngompa> 0.15.2-1.mga7
+ Revision: 1240907
- Rebase to libdnf 0.15.2
- Drop obsolete patches
- Drop gir subpackage and have lib package obsolete it (upstream removed it)

* Wed Oct 25 2017 ngompa <ngompa> 0.11.1-1.mga7
+ Revision: 1173651
- Upgrade to 0.11.1
- Backport patch to fix cleaning cache with versioned repo cache paths
- Backport patch to improve performance on query filters (rhbz#1500361)
- Backport patches to allow query expressions without spaces (rhbz#1480176)

* Fri Sep 01 2017 tv <tv> 0.9.3-4.mga7
+ Revision: 1150549
- rebuild for new rpm

* Sat Aug 05 2017 pterjan <pterjan> 0.9.3-3.mga7
+ Revision: 1135251
- Rebuild for python 3.6
+ tv <tv>
- rebuild for new python

* Sat Jul 29 2017 ngompa <ngompa> 0.9.3-1.mga7
+ Revision: 1132543
- Update to 0.9.3

* Sun Jul 02 2017 ngompa <ngompa> 0.9.2-1.mga6
+ Revision: 1108986
- Upgrade to 0.9.2

* Mon Jun 12 2017 ngompa <ngompa> 0.9.1-1.mga6
+ Revision: 1107576
- Update to 0.9.1

* Tue May 23 2017 ngompa <ngompa> 0.9.0-1.mga6
+ Revision: 1104146
- Upgrade to 0.9.0

* Wed May 03 2017 ngompa <ngompa> 0.8.2-1.mga6
+ Revision: 1098838
- Upgrade to v0.8.2

* Sun Apr 02 2017 ngompa <ngompa> 0.8.1-1.mga6
+ Revision: 1095673
- Update to 0.8.1

* Thu Mar 23 2017 ngompa <ngompa> 0.8.0-1.mga6
+ Revision: 1094579
- Upgrade to 0.8.0

* Sun Mar 19 2017 ngompa <ngompa> 0.7.4-1.mga6
+ Revision: 1093589
- Update to 0.7.4
- Add patch to add armv5tl to arm basearch
- Re-enable basic unit tests for armv5tl

* Thu Feb 16 2017 ngompa <ngompa> 0.7.3-1.mga6
+ Revision: 1086443
- Upgrade to 0.7.3

* Sun Dec 18 2016 ngompa <ngompa> 0.7.0-0.5.git20161218.378d315.mga6
+ Revision: 1075897
- Update to latest snapshot

* Fri Dec 02 2016 ngompa <ngompa> 0.7.0-0.4.git20161129.f9b798c.mga6
+ Revision: 1071664
- Update to latest snapshot

* Sun Nov 27 2016 ngompa <ngompa> 0.7.0-0.3.git20161125.2d8ba15.mga6
+ Revision: 1070490
- Bump for rebuilding against core/release

* Sat Nov 26 2016 ngompa <ngompa> 0.7.0-0.2.git20161125.2d8ba15.mga6
+ Revision: 1070222
- Disable running tests for armv5tl

* Sat Nov 26 2016 ngompa <ngompa> 0.7.0-0.1.git20161125.2d8ba15.mga6
+ Revision: 1070216
- Import from ngompa/dnf2-mga COPR


* Fri Nov 25 2016 Neal Gompa <ngompa13@gmail.com> - 0.7.0-0.1.git20161125.2d8ba15
- Bump to git commit 2d8ba15
- Drop merged patch

* Fri Nov 18 2016 Neal Gompa <ngompa13@gmail.com> - 0.7.0-0.0.3
- Bump to git commit 248dc84
- Add patch to fix mgabug:19744 / rbbug:1393595

* Thu Nov 10 2016 Neal Gompa <ngompa13@gmail.com> - 0.7.0-0.0.2
- Bump to git commit f102fd3

* Mon Oct 10 2016 Neal Gompa <ngompa13@gmail.com> - 0.7.0-0.0.1
- Initial packaging based on libhif and hawkey packages

